@@ -73,13 +73,15 @@ class TestAbstractInversion:
 
         matrix_shape = (9, 3)
 
-        inversion = inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
-            image=np.ones(9),
-            noise_map=np.ones(9),
-            convolver=mock.MockConvolver(matrix_shape),
-            mapper=mock.MockMapper(matrix_shape=matrix_shape),
-            regularization=mock.MockRegularization(matrix_shape),
-            settings=aa.SettingsInversion(check_solution=False),
+        inversion = (
+            inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
+                image=np.ones(9),
+                noise_map=np.ones(9),
+                convolver=mock.MockConvolver(matrix_shape),
+                mapper=mock.MockMapper(matrix_shape=matrix_shape),
+                regularization=mock.MockRegularization(matrix_shape),
+                settings=aa.SettingsInversion(check_solution=False),
+            )
         )
 
         inversion.reconstruction = np.array([1.0, 1.0, 1.0])
@@ -105,18 +107,20 @@ class TestAbstractInversion:
         assert inversion.regularization_term == 3.0
 
     def test__regularization_term__solution_and_regularization_matrix_range_of_values(
-        self
+        self,
     ):
 
         matrix_shape = (9, 3)
 
-        inversion = inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
-            image=np.ones(9),
-            noise_map=np.ones(9),
-            convolver=mock.MockConvolver(matrix_shape),
-            mapper=mock.MockMapper(matrix_shape),
-            regularization=mock.MockRegularization(matrix_shape),
-            settings=aa.SettingsInversion(check_solution=False),
+        inversion = (
+            inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
+                image=np.ones(9),
+                noise_map=np.ones(9),
+                convolver=mock.MockConvolver(matrix_shape),
+                mapper=mock.MockMapper(matrix_shape),
+                regularization=mock.MockRegularization(matrix_shape),
+                settings=aa.SettingsInversion(check_solution=False),
+            )
         )
 
         # G_l term, Warren & Dye 2003 / Nightingale /2015 2018
@@ -145,18 +149,20 @@ class TestAbstractInversion:
 
         matrix_shape = (9, 3)
 
-        inversion = inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
-            image=np.ones(9),
-            noise_map=np.ones(9),
-            convolver=mock.MockConvolver(matrix_shape),
-            mapper=mock.MockMapper(
-                matrix_shape,
-                pixelization_grid=aa.GridVoronoi.manual_1d(
-                    [[1.0, 2.0], [3.0, 4.0], [5.0, 6.0], [5.0, 0.0]]
+        inversion = (
+            inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
+                image=np.ones(9),
+                noise_map=np.ones(9),
+                convolver=mock.MockConvolver(matrix_shape),
+                mapper=mock.MockMapper(
+                    matrix_shape,
+                    pixelization_grid=aa.GridVoronoi.manual_1d(
+                        [[1.0, 2.0], [3.0, 4.0], [5.0, 6.0], [5.0, 0.0]]
+                    ),
                 ),
-            ),
-            regularization=mock.MockRegularization(matrix_shape),
-            settings=aa.SettingsInversion(check_solution=False),
+                regularization=mock.MockRegularization(matrix_shape),
+                settings=aa.SettingsInversion(check_solution=False),
+            )
         )
 
         inversion.reconstruction = np.array([2.0, 3.0, 5.0, 0.0])
@@ -165,11 +171,11 @@ class TestAbstractInversion:
         assert inversion.brightest_reconstruction_pixel_centre.in_list == [[(5.0, 6.0)]]
 
     def test__interpolated_reconstruction__config_is_image_grid__grid_as_mapper_with_good_interp(
-        self
+        self,
     ):
 
         conf.instance = conf.Config(
-            path.join(directory, "files/inversion_image_grid"),
+            path.join(directory, path.join("files", "inversion_image_grid")),
             path.join(directory, "output"),
         )
 
@@ -195,17 +201,19 @@ class TestAbstractInversion:
             shape_2d=(3, 3), pixel_scales=1.0, sub_size=1
         )
 
-        inversion = inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
-            image=np.ones(25),
-            noise_map=np.ones(25),
-            convolver=mock.MockConvolver(matrix_shape),
-            mapper=mock.MockMapper(
-                matrix_shape=matrix_shape,
-                grid=grid,
-                pixelization_grid=pixelization_grid,
-            ),
-            regularization=mock.MockRegularization(matrix_shape),
-            settings=aa.SettingsInversion(check_solution=False),
+        inversion = (
+            inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
+                image=np.ones(25),
+                noise_map=np.ones(25),
+                convolver=mock.MockConvolver(matrix_shape),
+                mapper=mock.MockMapper(
+                    matrix_shape=matrix_shape,
+                    grid=grid,
+                    pixelization_grid=pixelization_grid,
+                ),
+                regularization=mock.MockRegularization(matrix_shape),
+                settings=aa.SettingsInversion(check_solution=False),
+            )
         )
 
         inversion.reconstruction = np.array(
@@ -231,7 +239,7 @@ class TestAbstractInversion:
     def test__interpolated_errors__also_on_image_grid__interpolates_values(self):
 
         conf.instance = conf.Config(
-            path.join(directory, "files/inversion_image_grid"),
+            path.join(directory, path.join("files", "inversion_image_grid")),
             path.join(directory, "output"),
         )
 
@@ -257,17 +265,19 @@ class TestAbstractInversion:
             shape_2d=(3, 3), pixel_scales=1.0, sub_size=1
         )
 
-        inversion = inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
-            image=np.ones(25),
-            noise_map=np.ones(25),
-            convolver=mock.MockConvolver(matrix_shape),
-            mapper=mock.MockMapper(
-                matrix_shape=matrix_shape,
-                grid=grid,
-                pixelization_grid=pixelization_grid,
-            ),
-            regularization=mock.MockRegularization(matrix_shape),
-            settings=aa.SettingsInversion(check_solution=False),
+        inversion = (
+            inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
+                image=np.ones(25),
+                noise_map=np.ones(25),
+                convolver=mock.MockConvolver(matrix_shape),
+                mapper=mock.MockMapper(
+                    matrix_shape=matrix_shape,
+                    grid=grid,
+                    pixelization_grid=pixelization_grid,
+                ),
+                regularization=mock.MockRegularization(matrix_shape),
+                settings=aa.SettingsInversion(check_solution=False),
+            )
         )
 
         inversion.reconstruction = np.array(
@@ -285,10 +295,10 @@ class TestAbstractInversion:
         assert interpolated_errors.pixel_scales == pytest.approx((1.0, 1.0), 1.0e-4)
 
     def test__interpolated_reconstruction__config_is_source_grid__grid_is_zoomed_as_uses_mapper_grid(
-        self
+        self,
     ):
         conf.instance = conf.Config(
-            path.join(directory, "files/inversion_source_grid"),
+            path.join(directory, path.join("files", "inversion_source_grid")),
             path.join(directory, "output"),
         )
 
@@ -314,17 +324,19 @@ class TestAbstractInversion:
             shape_2d=(3, 3), pixel_scales=1.0, sub_size=1
         )
 
-        inversion = inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
-            image=np.ones(25),
-            noise_map=np.ones(25),
-            convolver=mock.MockConvolver(matrix_shape),
-            mapper=mock.MockMapper(
-                matrix_shape=matrix_shape,
-                grid=grid,
-                pixelization_grid=pixelization_grid,
-            ),
-            regularization=mock.MockRegularization(matrix_shape),
-            settings=aa.SettingsInversion(check_solution=False),
+        inversion = (
+            inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
+                image=np.ones(25),
+                noise_map=np.ones(25),
+                convolver=mock.MockConvolver(matrix_shape),
+                mapper=mock.MockMapper(
+                    matrix_shape=matrix_shape,
+                    grid=grid,
+                    pixelization_grid=pixelization_grid,
+                ),
+                regularization=mock.MockRegularization(matrix_shape),
+                settings=aa.SettingsInversion(check_solution=False),
+            )
         )
 
         inversion.reconstruction = np.array(
@@ -347,8 +359,8 @@ class TestAbstractInversion:
             (0.66666, 0.66666), 1.0e-4
         )
 
-        interpolated_reconstruction = inversion.interpolated_reconstruction_from_shape_2d(
-            shape_2d=(2, 2)
+        interpolated_reconstruction = (
+            inversion.interpolated_reconstruction_from_shape_2d(shape_2d=(2, 2))
         )
 
         assert (
@@ -365,8 +377,8 @@ class TestAbstractInversion:
             [1.0, 1.0, 1.0, 5.0, 5.0, 5.0, 5.0, 1.0, 1.0]
         )
 
-        interpolated_reconstruction = inversion.interpolated_reconstruction_from_shape_2d(
-            shape_2d=(2, 2)
+        interpolated_reconstruction = (
+            inversion.interpolated_reconstruction_from_shape_2d(shape_2d=(2, 2))
         )
 
         assert (
@@ -401,25 +413,27 @@ class TestAbstractInversion:
             shape_2d=(3, 3), pixel_scales=1.0, sub_size=1
         )
 
-        inversion = inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
-            image=np.ones(25),
-            noise_map=np.ones(25),
-            convolver=mock.MockConvolver(matrix_shape),
-            mapper=mock.MockMapper(
-                matrix_shape=matrix_shape,
-                grid=grid,
-                pixelization_grid=pixelization_grid,
-            ),
-            regularization=mock.MockRegularization(matrix_shape),
-            settings=aa.SettingsInversion(check_solution=False),
+        inversion = (
+            inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
+                image=np.ones(25),
+                noise_map=np.ones(25),
+                convolver=mock.MockConvolver(matrix_shape),
+                mapper=mock.MockMapper(
+                    matrix_shape=matrix_shape,
+                    grid=grid,
+                    pixelization_grid=pixelization_grid,
+                ),
+                regularization=mock.MockRegularization(matrix_shape),
+                settings=aa.SettingsInversion(check_solution=False),
+            )
         )
 
         inversion.reconstruction = np.array(
             [1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0]
         )
 
-        interpolated_reconstruction = inversion.interpolated_reconstruction_from_shape_2d(
-            shape_2d=(2, 2)
+        interpolated_reconstruction = (
+            inversion.interpolated_reconstruction_from_shape_2d(shape_2d=(2, 2))
         )
 
         assert (
@@ -436,8 +450,8 @@ class TestAbstractInversion:
             [1.0, 1.0, 1.0, 5.0, 5.0, 5.0, 5.0, 1.0, 1.0]
         )
 
-        interpolated_reconstruction = inversion.interpolated_reconstruction_from_shape_2d(
-            shape_2d=(2, 2)
+        interpolated_reconstruction = (
+            inversion.interpolated_reconstruction_from_shape_2d(shape_2d=(2, 2))
         )
 
         assert (
@@ -451,7 +465,7 @@ class TestAbstractInversion:
 
 class TestInversionImagingMatrix:
     def test__reconstruction_all_1s__simple_blurred_mapping_matrix__correct_reconstructed_image(
-        self
+        self,
     ):
 
         matrix_shape = (9, 3)
@@ -466,13 +480,15 @@ class TestInversionImagingMatrix:
 
         grid = aa.Grid.from_mask(mask=mask)
 
-        inversion = inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
-            image=np.ones(9),
-            noise_map=np.ones(9),
-            convolver=mock.MockConvolver(matrix_shape),
-            mapper=mock.MockMapper(matrix_shape=matrix_shape, grid=grid),
-            regularization=mock.MockRegularization(matrix_shape),
-            settings=aa.SettingsInversion(check_solution=False),
+        inversion = (
+            inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
+                image=np.ones(9),
+                noise_map=np.ones(9),
+                convolver=mock.MockConvolver(matrix_shape),
+                mapper=mock.MockMapper(matrix_shape=matrix_shape, grid=grid),
+                regularization=mock.MockRegularization(matrix_shape),
+                settings=aa.SettingsInversion(check_solution=False),
+            )
         )
 
         inversion.reconstruction = np.array([1.0, 1.0, 1.0, 1.0])
@@ -505,7 +521,7 @@ class TestInversionImagingMatrix:
         )
 
     def test__reconstruction_different_values__simple_blurred_mapping_matrix__correct_reconstructed_image(
-        self
+        self,
     ):
 
         matrix_shape = (9, 3)
@@ -520,13 +536,15 @@ class TestInversionImagingMatrix:
 
         grid = aa.Grid.from_mask(mask=mask)
 
-        inversion = inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
-            image=np.ones(9),
-            noise_map=np.ones(9),
-            convolver=mock.MockConvolver(matrix_shape),
-            mapper=mock.MockMapper(matrix_shape=matrix_shape, grid=grid),
-            regularization=mock.MockRegularization(matrix_shape),
-            settings=aa.SettingsInversion(check_solution=False),
+        inversion = (
+            inversions.InversionImagingMatrix.from_data_mapper_and_regularization(
+                image=np.ones(9),
+                noise_map=np.ones(9),
+                convolver=mock.MockConvolver(matrix_shape),
+                mapper=mock.MockMapper(matrix_shape=matrix_shape, grid=grid),
+                regularization=mock.MockRegularization(matrix_shape),
+                settings=aa.SettingsInversion(check_solution=False),
+            )
         )
 
         inversion.reconstruction = np.array([1.0, 2.0, 3.0, 4.0])
