@@ -150,8 +150,8 @@ class TestVisiblities:
 
         image = aa.Array.manual_2d([[2.0, 6.0]], pixel_scales=1.0)
 
-        real_visibilities_via_preload = transformer_preload.real_visibilities_from_image(
-            image=image
+        real_visibilities_via_preload = (
+            transformer_preload.real_visibilities_from_image(image=image)
         )
         real_visibilities = transformer.real_visibilities_from_image(image=image)
 
@@ -256,8 +256,8 @@ class TestVisiblities:
 
         image = aa.Array.manual_2d([[2.0, 6.0]], pixel_scales=1.0)
 
-        imag_visibilities_via_preload = transformer_preload.imag_visibilities_from_image(
-            image=image
+        imag_visibilities_via_preload = (
+            transformer_preload.imag_visibilities_from_image(image=image)
         )
         imag_visibilities = transformer.imag_visibilities_from_image(image=image)
 
@@ -311,8 +311,10 @@ class TestVisiblitiesMappingMatrix:
 
         mapping_matrix = np.ones(shape=(1, 1))
 
-        transformed_mapping_matrix = transformer.real_transformed_mapping_matrix_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrix = (
+            transformer.real_transformed_mapping_matrix_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         assert (transformed_mapping_matrix == np.ones(shape=(4, 1))).all()
@@ -332,8 +334,10 @@ class TestVisiblitiesMappingMatrix:
 
         mapping_matrix = np.ones(shape=(2, 1))
 
-        transformed_mapping_matrix = transformer.real_transformed_mapping_matrix_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrix = (
+            transformer.real_transformed_mapping_matrix_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         assert transformed_mapping_matrix == pytest.approx(
@@ -342,8 +346,10 @@ class TestVisiblitiesMappingMatrix:
 
         mapping_matrix = np.ones(shape=(2, 2))
 
-        transformed_mapping_matrix = transformer.real_transformed_mapping_matrix_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrix = (
+            transformer.real_transformed_mapping_matrix_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         assert transformed_mapping_matrix == pytest.approx(
@@ -370,8 +376,10 @@ class TestVisiblitiesMappingMatrix:
 
         mapping_matrix = np.array([[1.0], [0.0], [0.0]])
 
-        transformed_mapping_matrix = transformer.real_transformed_mapping_matrix_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrix = (
+            transformer.real_transformed_mapping_matrix_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         assert transformed_mapping_matrix == pytest.approx(
@@ -380,8 +388,10 @@ class TestVisiblitiesMappingMatrix:
 
         mapping_matrix = np.array([[0.0], [1.0], [0.0]])
 
-        transformed_mapping_matrix = transformer.real_transformed_mapping_matrix_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrix = (
+            transformer.real_transformed_mapping_matrix_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         assert transformed_mapping_matrix == pytest.approx(
@@ -390,8 +400,10 @@ class TestVisiblitiesMappingMatrix:
 
         mapping_matrix = np.array([[0.0, 0.5], [0.0, 0.2], [1.0, 0.0]])
 
-        transformed_mapping_matrix = transformer.real_transformed_mapping_matrix_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrix = (
+            transformer.real_transformed_mapping_matrix_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         assert transformed_mapping_matrix == pytest.approx(
@@ -420,12 +432,16 @@ class TestVisiblitiesMappingMatrix:
 
         mapping_matrix = np.array([[3.0, 5.0], [1.0, 2.0]])
 
-        transformed_mapping_matrix_preload = transformer_preload.real_transformed_mapping_matrix_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrix_preload = (
+            transformer_preload.real_transformed_mapping_matrix_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
-        transformed_mapping_matrix = transformer.real_transformed_mapping_matrix_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrix = (
+            transformer.real_transformed_mapping_matrix_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         assert (transformed_mapping_matrix_preload == transformed_mapping_matrix).all()
@@ -444,8 +460,10 @@ class TestVisiblitiesMappingMatrix:
 
         mapping_matrix = np.ones(shape=(1, 1))
 
-        transformed_mapping_matrix = transformer.imag_transformed_mapping_matrix_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrix = (
+            transformer.imag_transformed_mapping_matrix_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         assert transformed_mapping_matrix == pytest.approx(
@@ -466,8 +484,10 @@ class TestVisiblitiesMappingMatrix:
 
         mapping_matrix = np.ones(shape=(2, 1))
 
-        transformed_mapping_matrix = transformer.imag_transformed_mapping_matrix_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrix = (
+            transformer.imag_transformed_mapping_matrix_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         assert transformed_mapping_matrix == pytest.approx(
@@ -476,8 +496,10 @@ class TestVisiblitiesMappingMatrix:
 
         mapping_matrix = np.ones(shape=(2, 2))
 
-        transformed_mapping_matrix = transformer.imag_transformed_mapping_matrix_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrix = (
+            transformer.imag_transformed_mapping_matrix_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         assert transformed_mapping_matrix == pytest.approx(
@@ -504,8 +526,10 @@ class TestVisiblitiesMappingMatrix:
 
         mapping_matrix = np.array([[1.0], [0.0], [0.0]])
 
-        transformed_mapping_matrix = transformer.imag_transformed_mapping_matrix_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrix = (
+            transformer.imag_transformed_mapping_matrix_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         assert transformed_mapping_matrix == pytest.approx(
@@ -514,8 +538,10 @@ class TestVisiblitiesMappingMatrix:
 
         mapping_matrix = np.array([[0.0], [1.0], [0.0]])
 
-        transformed_mapping_matrix = transformer.imag_transformed_mapping_matrix_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrix = (
+            transformer.imag_transformed_mapping_matrix_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         assert transformed_mapping_matrix == pytest.approx(
@@ -524,8 +550,10 @@ class TestVisiblitiesMappingMatrix:
 
         mapping_matrix = np.array([[0.0, 0.5], [0.0, 0.2], [1.0, 0.0]])
 
-        transformed_mapping_matrix = transformer.imag_transformed_mapping_matrix_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrix = (
+            transformer.imag_transformed_mapping_matrix_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         assert transformed_mapping_matrix == pytest.approx(
@@ -554,18 +582,22 @@ class TestVisiblitiesMappingMatrix:
 
         mapping_matrix = np.array([[3.0, 5.0], [1.0, 2.0]])
 
-        transformed_mapping_matrix_preload = transformer_preload.imag_transformed_mapping_matrix_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrix_preload = (
+            transformer_preload.imag_transformed_mapping_matrix_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
-        transformed_mapping_matrix = transformer.imag_transformed_mapping_matrix_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrix = (
+            transformer.imag_transformed_mapping_matrix_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         assert (transformed_mapping_matrix_preload == transformed_mapping_matrix).all()
 
     def test__transformed_mapping_matrices_from_mapping_matrix__same_as_individual_calculations_above(
-        self
+        self,
     ):
 
         uv_wavelengths = np.array([[0.2, 1.0], [0.5, 1.1], [0.8, 1.2]])
@@ -582,8 +614,10 @@ class TestVisiblitiesMappingMatrix:
 
         mapping_matrix = np.ones(shape=(2, 1))
 
-        transformed_mapping_matrices = transformer.transformed_mapping_matrices_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrices = (
+            transformer.transformed_mapping_matrices_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         assert transformed_mapping_matrices[0] == pytest.approx(
@@ -643,8 +677,10 @@ class TestTransformerNUFFT:
             preload_transform=False,
         )
 
-        transformed_mapping_matrices_dft = transformer_dft.transformed_mapping_matrices_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrices_dft = (
+            transformer_dft.transformed_mapping_matrices_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         real_space_mask = aa.Mask2D.unmasked(shape_2d=(5, 5), pixel_scales=0.005)
@@ -653,8 +689,10 @@ class TestTransformerNUFFT:
             uv_wavelengths=uv_wavelengths, real_space_mask=real_space_mask
         )
 
-        transformed_mapping_matrices_nufft = transformer_nufft.transformed_mapping_matrices_from_mapping_matrix(
-            mapping_matrix=mapping_matrix
+        transformed_mapping_matrices_nufft = (
+            transformer_nufft.transformed_mapping_matrices_from_mapping_matrix(
+                mapping_matrix=mapping_matrix
+            )
         )
 
         assert transformed_mapping_matrices_dft[0] == pytest.approx(
