@@ -1,5 +1,4 @@
 from os import path
-import os
 import pytest
 
 from autoconf import conf
@@ -11,18 +10,19 @@ directory = path.dirname(path.realpath(__file__))
 
 
 @pytest.fixture(name="plot_path")
-def make_imaging_plotter_setup():
-    plot_path = "{}/files/plots/imaging/".format(
-        os.path.dirname(os.path.realpath(__file__))
+def make_plot_path_setup():
+    return path.join(
+        "{}".format(path.dirname(path.realpath(__file__))),
+        "files",
+        "plots",
+        "imaging",
     )
 
-    return plot_path
-
 
 @pytest.fixture(autouse=True)
 def set_config_path():
     conf.instance = conf.Config(
-        path.join(directory, "files/plotter"), path.join(directory, "output")
+        path.join(directory, "files", "plotter"), path.join(directory, "output")
     )
 
 
@@ -38,7 +38,7 @@ def test__individual_attributes_are_output(
         plotter=aplt.Plotter(output=aplt.Output(plot_path, format="png")),
     )
 
-    assert f"{plot_path}/image.png" in plot_patch.paths
+    assert path.join(plot_path, "image.png") in plot_patch.paths
 
     aplt.Imaging.noise_map(
         imaging=imaging_7x7,
@@ -46,14 +46,14 @@ def test__individual_attributes_are_output(
         plotter=aplt.Plotter(output=aplt.Output(plot_path, format="png")),
     )
 
-    assert f"{plot_path}/noise_map.png" in plot_patch.paths
+    assert path.join(plot_path, "noise_map.png") in plot_patch.paths
 
     aplt.Imaging.psf(
         imaging=imaging_7x7,
         plotter=aplt.Plotter(output=aplt.Output(plot_path, format="png")),
     )
 
-    assert f"{plot_path}/psf.png" in plot_patch.paths
+    assert path.join(plot_path, "psf.png") in plot_patch.paths
 
     aplt.Imaging.inverse_noise_map(
         imaging=imaging_7x7,
@@ -61,7 +61,7 @@ def test__individual_attributes_are_output(
         plotter=aplt.Plotter(output=aplt.Output(plot_path, format="png")),
     )
 
-    assert f"{plot_path}/inverse_noise_map.png" in plot_patch.paths
+    assert path.join(plot_path, "inverse_noise_map.png") in plot_patch.paths
 
     aplt.Imaging.signal_to_noise_map(
         imaging=imaging_7x7,
@@ -69,7 +69,7 @@ def test__individual_attributes_are_output(
         plotter=aplt.Plotter(output=aplt.Output(plot_path, format="png")),
     )
 
-    assert f"{plot_path}/signal_to_noise_map.png" in plot_patch.paths
+    assert path.join(plot_path, "signal_to_noise_map.png") in plot_patch.paths
 
 
 def test__subplot_is_output(
@@ -81,7 +81,7 @@ def test__subplot_is_output(
         sub_plotter=aplt.SubPlotter(output=aplt.Output(plot_path, format="png")),
     )
 
-    assert f"{plot_path}/subplot_imaging.png" in plot_patch.paths
+    assert path.join(plot_path, "subplot_imaging.png") in plot_patch.paths
 
 
 def test__imaging_individuals__output_dependent_on_input(
@@ -96,19 +96,19 @@ def test__imaging_individuals__output_dependent_on_input(
         plotter=aplt.Plotter(output=aplt.Output(plot_path, format="png")),
     )
 
-    assert f"{plot_path}/image.png" in plot_patch.paths
+    assert path.join(plot_path, "image.png") in plot_patch.paths
 
-    assert not f"{plot_path}/noise_map.png" in plot_patch.paths
+    assert not path.join(plot_path, "noise_map.png") in plot_patch.paths
 
-    assert f"{plot_path}/psf.png" in plot_patch.paths
+    assert path.join(plot_path, "psf.png") in plot_patch.paths
 
-    assert f"{plot_path}/inverse_noise_map.png" in plot_patch.paths
+    assert path.join(plot_path, "inverse_noise_map.png") in plot_patch.paths
 
-    assert not f"{plot_path}/signal_to_noise_map.png" in plot_patch.paths
+    assert not path.join(plot_path, "signal_to_noise_map.png") in plot_patch.paths
 
-    assert f"{plot_path}/absolute_signal_to_noise_map.png" in plot_patch.paths
+    assert path.join(plot_path, "absolute_signal_to_noise_map.png") in plot_patch.paths
 
-    assert not f"{plot_path}/potential_chi_squared_map.png" in plot_patch.paths
+    assert not path.join(plot_path, "potential_chi_squared_map.png") in plot_patch.paths
 
 
 def test__output_as_fits__correct_output_format(
@@ -124,7 +124,7 @@ def test__output_as_fits__correct_output_format(
     )
 
     image_from_plot = aa.util.array.numpy_array_2d_from_fits(
-        file_path=f"{plot_path}/image.fits", hdu=0
+        file_path=path.join(plot_path, "image.fits"), hdu=0
     )
 
     assert image_from_plot.shape == (7, 7)
